pub struct TickStatus { /* private fields */ }Expand description
Tracks the simulation’s progress through time ticks, including handled skips.
Implementations
Sourceimpl TickStatus
impl TickStatus
Sourcepub fn skipped(&self) -> Duration
pub fn skipped(&self) -> Duration
Returns the total duration of time that has been skipped from previous tick.
Sourcepub fn is_done_ticks(
&self,
include_zero_tick: bool,
tick_count: TimeTick,
) -> bool
pub fn is_done_ticks( &self, include_zero_tick: bool, tick_count: TimeTick, ) -> bool
Determines if the simulation has processed the required number of ticks.
This uses the previous() time as a baseline to handle cases where time
is skipped. Even if a large jump occurs, it ensures the simulation processes
up to the threshold before stopping safely.
Arguments
include_zero_tick- Iftrue, the zero-th tick is included in the count.tick_count- The target tick threshold to reach.